@@ -36,16 +36,16 @@ class CryptoModel:
         self.mode = mode
 
     @staticmethod
-    def padding(text):
+    def padding(text: bytes):
         padding_0a = (16 - len(text) % 16) * b' '
-        return text.encode('utf-8') + padding_0a
+        return text + padding_0a
 
-    def aes_encode(self, text):
+    def aes_encode(self, text: bytes):
         obj = AES.new(self.key, self.mode, self.iv)
         data = self.padding(text)
         return obj.encrypt(data)
 
-    def aes_decode(self, data):
+    def aes_decode(self, data: bytes):
         obj = AES.new(self.key, self.mode, self.iv)
         return obj.decrypt(data)
 
