@@ -1,7 +1,8 @@
 # coding: utf-8
 import os
-import platform
+import sys
 import traceback
+from pathlib import Path
 
 """
 路径类
@@ -10,7 +11,7 @@ import traceback
 第二个开始表示该方法的作用/效果/含义
 """
 
-SYS: str = platform.system()
+SYS: str = sys.platform
 
 
 def abs_cwd_base(path):
@@ -57,7 +58,7 @@ def abs_find_program(program):
     :return: the full path to the binary.
     :todo: add a default path list in case PATH is empty.
     """
-    __is_windows = (SYS == 'Windows')
+    __is_windows = (SYS == 'win32')
     split_char = ';' if __is_windows else ':'
     program = program + '.exe' if __is_windows else program
     paths = os.environ.get('PATH', '').split(split_char)
@@ -87,7 +88,7 @@ def abs_find_real_link(bath_path: str):
 
 
 def safe_path(path):
-    return path.replace('/', '\\') if SYS == 'Windows' else path.replace('\\', '/')
+    return path.replace('/', '\\') if SYS == 'win32' else path.replace('\\', '/')
 
 
 def _combine_path(path_a, path_b):
